==> kde4pim_3.92.0.orig.tar.gz: kdepim-3.92.0/kaddressbook/kcmconfigs/addresseewidget.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef ADDRESSEEWIDGET_H
#define ADDRESSEEWIDGET_H

#include <QWidget>

class KComboBox;

class Q3ListBox;
class Q3ListBoxItem;
class QPushButton;

class NamePartWidget : public QWidget
{
  Q_OBJECT

  public:
    NamePartWidget( const QString &title, const QString &label, QWidget *parent,
                    const char *name = 0 );
    ~NamePartWidget();

    void setNameParts( const QStringList &list );
    QStringList nameParts() const;

  signals:
    void modified();

  private slots:
    void add();
    void edit();
    void remove();

    void selectionChanged( Q3ListBoxItem* );

  private:
    Q3ListBox *mBox;
    QPushButton *mAddButton;
    QPushButton *mEditButton;
    QPushButton *mRemoveButton;

    QString mTitle;
    QString mLabel;
};

class AddresseeWidget : public QWidget
{
  Q_OBJECT

  public:
    AddresseeWidget( QWidget *parent, const char *name = 0 );
    ~AddresseeWidget();

    void restoreSettings();
    void saveSettings();

  signals:
    void modified();

  private:
    KComboBox *mFormattedNameCombo;
    NamePartWidget *mPrefix;
    NamePartWidget *mInclusion;
    NamePartWidget *mSuffix;
};

#endif

==> kde4pim_3.94.0.orig.tar.gz: kdepim-3.94.0/kaddressbook/kcmconfigs/addresseewidget.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef ADDRESSEEWIDGET_H
#define ADDRESSEEWIDGET_H

#include <QWidget>

class KComboBox;

class QListWidget;
class QListWidgetItem;
class QPushButton;

class NamePartWidget : public QWidget
{
  Q_OBJECT

  public:
    NamePartWidget( const QString &title, const QString &label, QWidget *parent,
                    const char *name = 0 );
    ~NamePartWidget();

    void setNameParts( const QStringList &list );
    QStringList nameParts() const;

  signals:
    void modified();

  private slots:
    void add();
    void edit();
    void remove();

    void selectionChanged( QListWidgetItem * );

  private:
    QListWidget *mBox;
    QPushButton *mAddButton;
    QPushButton *mEditButton;
    QPushButton *mRemoveButton;

    QString mTitle;
    QString mLabel;
};

class AddresseeWidget : public QWidget
{
  Q_OBJECT

  public:
    AddresseeWidget( QWidget *parent, const char *name = 0 );
    ~AddresseeWidget();

    void restoreSettings();
    void saveSettings();

  signals:
    void modified();

  private:
    KComboBox *mFormattedNameCombo;
    NamePartWidget *mPrefix;
    NamePartWidget *mInclusion;
    NamePartWidget *mSuffix;
};

#endif
